==> qgis-3.0.3-1-armv7h.pkg.tar.xz: usr/share/qgis/python/plugins/processing/algs/grass7/ext/v_extrude.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    v_extrude.py
    ------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'


def checkParameterValuesBeforeExecuting(alg, parameters, context):
    """ Verify if we have the right parameters """
    height = alg.parameterAsDouble(parameters, 'height', context)
    height_column = alg.parameterAsString(parameters, 'height_column', context)
    if (height and height_column) or (not height and not height_column):
        return alg.tr("You need to set either a fixed height value or the height column!")

    return None

==> qgis-3.2.1-1-armv7h.pkg.tar.xz: usr/share/qgis/python/plugins/processing/algs/grass7/ext/v_extrude.py <==
# -*- coding: utf-8 -*-

"""
***************************************************************************
    v_extrude.py
    ------------
    Date                 : March 2016
    Copyright            : (C) 2016 by Médéric Ribreux
    Email                : medspx at medspx dot fr
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Médéric Ribreux'
__date__ = 'March 2016'
__copyright__ = '(C) 2016, Médéric Ribreux'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '1edf372fb80f2a35c77b128dc143c0f3c97cd8f3'


def checkParameterValuesBeforeExecuting(alg, parameters, context):
    """ Verify if we have the right parameters """
    height = alg.parameterAsDouble(parameters, 'height', context)
    height_column = alg.parameterAsString(parameters, 'height_column', context)
    if (height and height_column) or (not height and not height_column):
        return False, alg.tr("You need to set either a fixed height value or the height column!")

    return True, None
